package net.plil.clubinfo.etunicorn.app.event;

import android.content.Context;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.PopupMenu;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import net.plil.clubinfo.etunicorn.R;
import net.plil.clubinfo.etunicorn.data.Event;

import java.util.List;
import java.util.Locale;


public class MyEventRecyclerViewAdapter extends RecyclerView.Adapter<MyEventRecyclerViewAdapter.ViewHolder> {

    private final List<Event> mEvents;
    private final EventFragment.OnListFragmentInteractionListener mListener;
    private final Context context;

    public MyEventRecyclerViewAdapter(List<Event> items, EventFragment.OnListFragmentInteractionListener listener, Context context) {
        mEvents = items;
        mListener = listener;
        this.context = context;
    }

    @Override
    public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.fragment_event, parent, false);
        return new ViewHolder(view);
    }

    @Override
    public void onBindViewHolder(final ViewHolder holder, int position) {
        holder.mItem = mEvents.get(position);
        holder.mContentView.setText(mEvents.get(position).getNomEvent());
        holder.mPriceView.setText(String.format(Locale.FRANCE, "%.2f", mEvents.get(position).getPrice()));
        holder.mId = mEvents.get(position).getIdEvent();

        holder.mView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (null != mListener) {
                    mListener.onListFragmentInteraction(holder.mItem);
                }
            }
        });

        holder.mView.setOnLongClickListener(new View.OnLongClickListener() {
            @Override
            public boolean onLongClick(View v) {
                mListener.onListFragmentInteractionLong(holder.mItem);
                return true;
            }
        });

        holder.mButtonView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                final PopupMenu popup = new PopupMenu(v.getContext(), holder.mButtonView);
                //inflating menu from xml resource
                popup.inflate(R.menu.option_list);
                //adding click listener
                popup.setOnMenuItemClickListener(new PopupMenu.OnMenuItemClickListener() {
                    @Override
                    public boolean onMenuItemClick(MenuItem item) {
                        switch (item.getItemId()) {
                            case R.id.delete:
                                DeleteEvent deleteEvent = DeleteEvent.newInstance(holder.mItem);
                                deleteEvent.show(((AppCompatActivity) context).getSupportFragmentManager(), "deleteConsommation");
                                break;
                            case R.id.modify:
                                ModifyEvent modifyEvent = ModifyEvent.newInstance(holder.mItem);
                                modifyEvent.show(((AppCompatActivity) context).getSupportFragmentManager(), "modifyConsommation");
                                break;
                        }
                        return false;
                    }
                });
                //displaying the popup
                popup.show();
            }
        });

    }

    @Override
    public int getItemCount() {
        return mEvents.size();
    }

    class ViewHolder extends RecyclerView.ViewHolder {
        final View mView;
        int mId;
        final TextView mContentView;
        final TextView mPriceView;
        final TextView mButtonView;
        Event mItem;

        public ViewHolder(View view) {
            super(view);
            mView = view;
            mContentView = (TextView) view.findViewById(R.id.event_name);
            mPriceView = (TextView) view.findViewById(R.id.event_price);
            mButtonView = (TextView) view.findViewById(R.id.event_options);
        }

    }
}
