package net.plil.clubinfo.etunicorn.app.personne;

import android.app.Dialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.support.v7.app.AlertDialog;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.EditText;
import android.widget.ProgressBar;
import android.widget.Toast;

import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.JsonObjectRequest;

import net.plil.clubinfo.etunicorn.R;
import net.plil.clubinfo.etunicorn.data.Event;
import net.plil.clubinfo.etunicorn.data.Personne;
import net.plil.clubinfo.etunicorn.utils.VolleyUtils;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.Locale;


public class ModifyPersonne extends DialogFragment {

    EditText mCarte;
    EditText mNaissance;
    EditText mLogin;
    EditText mRole;
    ProgressBar mProgressBar;

    public static ModifyPersonne newInstance(Personne personne) {
        ModifyPersonne f = new ModifyPersonne();

        // Supply num input as an argument.
        Bundle args = new Bundle();
        args.putSerializable("personne", personne);
        f.setArguments(args);

        return f;
    }


    @Override
    public Dialog onCreateDialog(Bundle savedInstanceState) {
        // Use the Builder class for convenient dialog construction
        LayoutInflater inflater = getActivity().getLayoutInflater();
        View view = inflater.inflate(R.layout.fragment_modify_personne, null);
        mLogin = (EditText) view.findViewById(R.id.modify_personne_login);
        mCarte = (EditText) view.findViewById(R.id.modify_personne_carte);
        mNaissance = (EditText) view.findViewById(R.id.modify_personne_naissance);
        mRole = (EditText) view.findViewById(R.id.modify_personne_role);
        mProgressBar = (ProgressBar) view.findViewById(R.id.modify_event_progress_bar);

        final Personne personne = (Personne) getArguments().getSerializable("personne");

        mRole.setText(personne.getRole().getName());
        mCarte.setText(personne.getIdCarte());
        mLogin.setText(personne.getLoginPoly());
        mNaissance.setText(personne.getNaissance().toString());

        AlertDialog.Builder builder = new AlertDialog.Builder(getActivity());
        builder
                .setTitle(R.string.modify)
                .setView(view)
                .setPositiveButton(R.string.modify, new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int id) {

                        mProgressBar.setVisibility(View.VISIBLE);
                        mRole.setVisibility(View.GONE);
                        mLogin.setVisibility(View.GONE);
                        mCarte.setVisibility(View.GONE);
                        mNaissance.setVisibility(View.GONE);
                        JSONObject jsonObject = new JSONObject();
                        try {
                            jsonObject.put("carte", mCarte.getText().toString());
                            jsonObject.put("login", mLogin.getText().toString());
                            jsonObject.put("role", mRole.getText().toString());
                            jsonObject.put("naissance", mNaissance.getText().toString());
                        } catch (JSONException e){
                            e.printStackTrace();
                        }
                        JsonObjectRequest jsonObjectRequest = new JsonObjectRequest(Request.Method.POST, VolleyUtils.baseUri + "/personne/" + personne.getIdPersonne() ,jsonObject , new Response.Listener<JSONObject>() {
                            @Override
                            public void onResponse(JSONObject response) {
                                mProgressBar.setVisibility(View.GONE);
                                Toast.makeText(getContext(), R.string.modify_done, Toast.LENGTH_LONG).show();

                            }
                        }, new Response.ErrorListener() {
                            @Override
                            public void onErrorResponse(VolleyError error) {
                                mProgressBar.setVisibility(View.GONE);
                                Toast.makeText(getContext(), R.string.modify_refused, Toast.LENGTH_LONG).show();

                            }
                        }
                        );

                        VolleyUtils.getInstance(getContext()).addToRequestQueue(jsonObjectRequest);
                    }
                })
                .setNegativeButton(R.string.cancel, new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int id) {
                        // User cancelled the dialog
                    }
                });
        // Create the AlertDialog object and return it
        return builder.create();
    }


}
